@@ -36,7 +36,17 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
+#endif
+#if !defined (HAVE_UNISTD_H) && defined(_WIN64)
+#include <io.h>
+#define read _read
+#define write _write
+#define close _close
+#define lseek _lseek
+#define ftruncate _chsize_s
+#endif
 #include <string.h>
 #include <errno.h>
 
@@ -65,6 +75,7 @@
 
 #ifdef G_OS_WIN32
 #define BINARY_FLAG O_BINARY
+#define F_OK 0
 #else
 #define BINARY_FLAG 0
 #endif
