@@ -89,7 +89,7 @@ static gboolean   gegl_tile_handler_cache_copy       (GeglTileHandlerCache     *
 static GMutex             mutex                 = { 0, };
 static GQueue             cache_queue           = G_QUEUE_INIT;
 static gint               cache_wash_percentage = 20;
-static volatile guintptr  cache_total           = 0; /* approximate amount of bytes stored */
+static          guintptr  cache_total           = 0; /* approximate amount of bytes stored */
 static guintptr           cache_total_max       = 0; /* maximal value of cache_total */
 static volatile guintptr  cache_total_uncloned  = 0; /* approximate amount of uncloned bytes stored */
 static gint               cache_hits            = 0;
@@ -480,7 +480,7 @@ gegl_tile_handler_cache_get_tile (GeglTileHandlerCache *cache,
       g_queue_unlink (&cache->queue, &result->link);
       g_queue_push_head_link (&cache->queue, &result->link);
       cache->time = ++cache_time;
-      while (result->tile == NULL)
+      if (result->tile == NULL)
       {
         g_printerr ("NULL tile in %s %p %i %i %i %p\n", __FUNCTION__, result, result->x, result->y, result->z,
                 result->tile);
@@ -902,7 +902,7 @@ gegl_tile_handler_cache_insert (GeglTileHandlerCache *cache,
   else
     total = (guintptr) g_atomic_pointer_get (&cache_total);
   g_atomic_pointer_add (&cache_total_uncloned, tile->size);
-  g_hash_table_insert (cache->items, item, item);
+  g_hash_table_add (cache->items, item);
   g_queue_push_head_link (&cache->queue, &item->link);
 
   if (total > gegl_buffer_config ()->tile_cache_size)
