@@ -64,7 +64,8 @@ struct _GeglTileStorageClass
 GType gegl_tile_storage_get_type (void) G_GNUC_CONST;
 
 GeglTileStorage *
-gegl_tile_storage_new (GeglTileBackend *backend);
+gegl_tile_storage_new (GeglTileBackend *backend,
+                       gboolean         initialized);
 
 void gegl_tile_storage_add_handler (GeglTileStorage *tile_storage, GeglTileHandler *handler);
 void gegl_tile_storage_remove_handler (GeglTileStorage *tile_storage, GeglTileHandler *handler);
