@@ -231,17 +231,17 @@ static const GeglModuleInfo modinfo =
 };
 
 /* prototypes added to silence warnings from gcc for -Wmissing-prototypes*/
-gboolean                gegl_module_register (GTypeModule *module);
-const GeglModuleInfo  * gegl_module_query    (GTypeModule *module);
+G_MODULE_EXPORT gboolean                gegl_module_register (GTypeModule *module);
+G_MODULE_EXPORT const GeglModuleInfo  * gegl_module_query    (GTypeModule *module);
 
 #ifndef GEGL_OP_BUNDLE
-G_MODULE_EXPORT const GeglModuleInfo *
+const GeglModuleInfo *
 gegl_module_query (GTypeModule *module)
 {
   return &modinfo;
 }
 
-G_MODULE_EXPORT gboolean
+gboolean
 gegl_module_register (GTypeModule *module)
 {
 #define do_reg_(a) gegl_op_##a##_register_type (module)
@@ -856,7 +856,7 @@ gegl_op_class_intern_init (gpointer klass)
     }
 
 #define description(blurb) \
-    pspec->_blurb = g_strdup (blurb);
+    pspec->_blurb = g_markup_escape_text (blurb, -1);
 #define value_range(min,max) \
     vpspec->minimum = min; vpspec->maximum = max; \
     upspec->ui_minimum = min; upspec->ui_maximum = max;
