@@ -31,6 +31,9 @@
 #include <glib.h>
 #include <gmodule.h>
 #include <string.h>
+#ifdef _WIN64
+#define strdup _strdup
+#endif
 #include <stdio.h>
 
 #include "gegl-cl.h"
@@ -382,7 +385,9 @@ static gboolean
 gegl_cl_init_get_gl_sharing_props (cl_context_properties   gl_contex_props[64],
                                    GError                **error)
 {
+#ifndef _WIN32
   static gboolean gl_loaded = FALSE;
+#endif
 
   #if defined(__APPLE__)
   CGLContextObj kCGLContext;
