@@ -313,8 +313,13 @@ rgbe_header_read_variables (rgbe_file *file,
           else
             {
               guint linesize = lineend - data;
+#ifndef _WIN64
               strncpy (file->header.software, data,
                        MIN (linesize, G_N_ELEMENTS (file->header.software) - 1));
+#else
+              strncpy_s (file->header.software, sizeof(file->header.software),
+                         data, _TRUNCATE);
+#endif
             }
         }
 
@@ -932,7 +937,19 @@ rgbe_save_path (const gchar *path,
   FILE        *f       = NULL;
   gboolean     success = FALSE;
 
+#ifndef _WIN64
   f = (!strcmp (path, "-") ? stdout : fopen(path, "wb"));
+#else
+  if (!strcmp (path, "-"))
+    {
+      f = stdout;
+    }
+  else if (fopen_s(&f, path, "wb") != 0)
+    {
+      f = NULL;
+    }
+#endif
+
   if (!f)
       goto cleanup;
 
