@@ -18,6 +18,9 @@
 
 #include "config.h"
 #include <glib/gi18n-lib.h>
+#if defined(_WIN64) && !defined(read)
+#define read _read
+#endif
 
 #ifdef GEGL_PROPERTIES
 
