@@ -58,7 +58,7 @@ operation_process (GeglOperation        *operation,
 
   input  = (GeglBuffer*) gegl_operation_context_get_object (context, "input");
 
-  if (gegl_buffer_get_format (input) == o->format)
+  if (! o->format || gegl_buffer_get_format (input) == o->format)
     {
       gegl_operation_context_set_object (context, "output", G_OBJECT (input));
 
@@ -89,11 +89,10 @@ gegl_op_class_init (GeglOpClass *klass)
   GeglOperationClass       *operation_class = GEGL_OPERATION_CLASS (klass);
   GeglOperationFilterClass *filter_class    = GEGL_OPERATION_FILTER_CLASS (klass);
 
-  operation_class->prepare  = prepare;
-  operation_class->process  = operation_process;
-  operation_class->no_cache = FALSE;
+  operation_class->prepare = prepare;
+  operation_class->process = operation_process;
 
-  filter_class->process     = process;
+  filter_class->process    = process;
 
   gegl_operation_class_set_keys (operation_class,
                 "name",       "gegl:convert-format",
