@@ -596,7 +596,7 @@ query_tiff(GeglOperation *operation)
       {
         const char *error = NULL;
         space = babl_space_from_icc ((char*)icc_profile, (gint)profile_size,
-                                     BABL_ICC_INTENT_RELATIVE_COLORIMETRIC, &error);
+                                     BABL_ICC_INTENT_DEFAULT, &error);
         if (error)
           g_warning ("error creating space from icc: %s\n", error);
       }
